This crate is part of the Conformal Framework! For high-level documentation and tutorials, please see the main documentation website!
This crate contains operations for working with macOS bundles.
Structs
Enums
Functions
- Get the bundle info for the bundle this was compiled into.